package net.nevet5.buzzbot.commands;

import net.dv8tion.jda.api.EmbedBuilder;
import net.dv8tion.jda.api.entities.TextChannel;
import net.nevet5.buzzbot.Config;
import net.nevet5.buzzbot.commands.utils.CommandContext;
import net.nevet5.buzzbot.commands.utils.CommandManager;
import net.nevet5.buzzbot.commands.utils.ICommand;

import java.util.List;

public class HelpCmd implements ICommand {

    private final CommandManager manager;

    public HelpCmd(CommandManager manager) {
        this.manager = manager;
    }

    @Override
    public void handle(CommandContext ctx) {
        List<String> args = ctx.getArgs();
        TextChannel channel = ctx.getChannel();

        if (args.isEmpty()) {
            StringBuilder builder = new StringBuilder();

            EmbedBuilder eb = new EmbedBuilder();

            eb.setTitle("List of Commands");

            manager.getCommands().stream().map(ICommand::getName).forEach(
                    (it) -> builder.append('`').append(Config.getConfig().getString("bot.prefix")).append(it).append("`\n")
            );

            eb.addField("", builder.toString(), false);
            channel.sendMessageEmbeds(eb.build()).queue();

            return;
        }

        String search = args.get(0);
        ICommand command = manager.getCommand(search);

        if (command == null) {
            channel.sendMessage("Nothing found for " + search);
            return;
        }

        channel.sendMessage(command.getHelp()).queue();
    }

    @Override
    public String getName() {
        return "help";
    }

    @Override
    public String getHelp() {
        return "Shows the list of bot commands\n" +
                "Usage: `" + Config.getConfig().getString("bot.prefix") + "help [command]`";
    }

    @Override
    public List<String> getAliases() {
        return List.of("commands", "cmds", "commandlist");
    }
}
